@@ -370,13 +370,15 @@ def trigger_set_value_task(set_value_fields, conf, rule, session_name, vtiger_ac
 
     print("Inside trigger_set_value_task")
     id = conf.get('data').get('id', '')
+    lead_id = conf.get('data').get('lead_id', '')
     record_module = 'Leads'
     module = module_id_dict.get(record_module, '')
     print("Id: {}".format(id))
+    print("lead_id: {}".format(lead_id))
+    final_id = id if id else lead_id
     print("Module {}".format(module))
-    if id and record_module:
-
-        id = id if "x" in id else module + 'x' + id
+    if final_id and record_module:
+        id = final_id if "x" in final_id else module + 'x' + final_id
         element = {"id": str(id)}
 
         for record in set_value_fields:
